@@ -11,9 +11,9 @@ from cmor.pywrapper import (
     close, grid, set_grid_mapping, time_varying_grid_coordinate, dataset_json,
     set_cur_dataset_attribute, get_cur_dataset_attribute,
     has_cur_dataset_attribute, set_variable_attribute, get_variable_attribute,
-    has_variable_attribute, get_final_filename, set_deflate, set_furtherinfourl, 
-    set_climatology, get_climatology, set_terminate_signal, get_terminate_signal,
-    calculate_leadtime_coord)
+    has_variable_attribute, get_final_filename, set_deflate, set_zstandard,
+    set_quantize, set_furtherinfourl, set_climatology, get_climatology,
+    set_terminate_signal, get_terminate_signal)
 
 try:
     from check_CMOR_compliant import checkCMOR
