@@ -18,7 +18,7 @@ import unittest
 import sys
 import os
 import tempfile
-
+import base_CMIP6_CV
 
 # ==============================
 #  main thread
@@ -28,40 +28,14 @@ import tempfile
 def run():
     unittest.main()
 
-
-class TestCase(unittest.TestCase):
-    def setUp(self, *args, **kwargs):
-        # ------------------------------------------------------
-        # Copy stdout and stderr file descriptor for cmor output
-        # ------------------------------------------------------
-        self.newstdout = os.dup(1)
-        self.newstderr = os.dup(2)
-        # --------------
-        # Create tmpfile
-        # --------------
-        self.tmpfile = tempfile.mkstemp()
-        os.dup2(self.tmpfile[0], 1)
-        os.dup2(self.tmpfile[0], 2)
-        os.close(self.tmpfile[0])
-
-    def getAssertTest(self):
-        f = open(self.tmpfile[1], 'r')
-        lines = f.readlines()
-        for line in lines:
-            if line.find('source type is set to') != -1:
-                testOK = line.strip()
-                break
-        f.close()
-        os.unlink(self.tmpfile[1])
-        return testOK
-
+class TestCase(base_CMIP6_CV.BaseCVsTest):
     def testCMIP6(self):
         try:
             # -------------------------------------------
             # Try to call cmor with a bad institution_ID
             # -------------------------------------------
-            cmor.setup(inpath='Tables', netcdf_file_action=cmor.CMOR_REPLACE)
-            cmor.dataset_json("Test/common_user_input.json")
+            cmor.setup(inpath='Tables', netcdf_file_action=cmor.CMOR_REPLACE, logfile=self.tmpfile)
+            cmor.dataset_json("Test/CMOR_input_example.json")
             cmor.set_cur_dataset_attribute(
                 "source_type", "AOGCM ISM BGCM LAND")
 
@@ -80,23 +54,14 @@ class TestCase(unittest.TestCase):
             data = numpy.random.random(5)
             for i in range(0, 5):
                 a = cmor.write(ivar, data[i:i])
+            self.delete_files += [cmor.close(ivar, True)]
             cmor.close()
-
         except BaseException:
             pass
-        os.dup2(self.newstdout, 1)
-        os.dup2(self.newstderr, 2)
-        sys.stdout = os.fdopen(self.newstdout, 'w', 0)
-        sys.stderr = os.fdopen(self.newstderr, 'w', 0)
-        testOK = self.getAssertTest()
         # ------------------------------------------
         # Check error after signal handler is back
         # ------------------------------------------
-        self.assertIn("\"AOGCM ISM BGCM LAND\"", testOK)
-
-    def tearDown(self):
-        import shutil
-        shutil.rmtree("./CMIP6")
+        self.assertCV("\"AOGCM ISM BGCM LAND\"", "source type is set to")
 
 
 if __name__ == '__main__':
