@@ -2,7 +2,7 @@
 #define CMOR_H
 
 #define CMOR_VERSION_MAJOR 3
-#define CMOR_VERSION_MINOR 8
+#define CMOR_VERSION_MINOR 9
 #define CMOR_VERSION_PATCH 0
 
 #define CMOR_CF_VERSION_MAJOR 1
@@ -134,6 +134,9 @@
 #define VARIABLE_ATT_SHUFFLE          "shuffle"
 #define VARIABLE_ATT_DEFLATE          "deflate"
 #define VARIABLE_ATT_DEFLATELEVEL     "deflate_level"
+#define VARIABLE_ATT_ZSTANDARDLEVEL   "zstandard_level"
+#define VARIABLE_ATT_QUANTIZEMODE     "quantize_mode"
+#define VARIABLE_ATT_QUANTIZENSD      "quantize_nsd"
 #define VARIABLE_ATT_MODELINGREALM    "modeling_realm"
 #define VARIALBE_ATT_FREQUENCY        "frequency"
 #define VARIABLE_ATT_FLAGVALUES       "flag_values"
@@ -422,6 +425,9 @@ typedef struct cmor_variable_def_ {
     int shuffle;
     int deflate;
     int deflate_level;
+    int zstandard_level;
+    int quantize_mode;
+    int quantize_nsd;
     char required[CMOR_MAX_STRING];
     char realm[CMOR_MAX_STRING];
     char frequency[CMOR_MAX_STRING];
@@ -473,6 +479,9 @@ typedef struct cmor_var_ {
     int shuffle;
     int deflate;
     int deflate_level;
+    int zstandard_level;
+    int quantize_mode;
+    int quantize_nsd;
     int nomissing;
     char iunits[CMOR_MAX_STRING];
     char ounits[CMOR_MAX_STRING];
